//-----------------------------------------------------------------------------------
// eOn is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// A copy of the GNU General Public License is available at
// http://www.gnu.org/licenses/
//-----------------------------------------------------------------------------------

#ifndef POTENTIAL_H
#define POTENTIAL_H

//#include "Parameters.h"
//#include "Eigen.h"


/* 
L.J. Karssemeijer 2014.

Forward declarations, to allow complilation of h2ococo2pot class.
Do not use this version of Potential.h 
Replace with official EON version!
*/
class VectorXi;
class Vector3d;
class Matrix3d;
class AtomMatrix;
class Parameters;

class Potential
{

    public:

        Potential(){ std::cout << "Potential constructor"<<std::endl;}
        virtual ~Potential(){}

        static const char POT_LJ[];

        static const char POT_H2OCOCO2[];
        static const char POT_TIP4P2005F_H[];
        static const char POT_LAMMPS[];
        static Potential* getPotential(Parameters *parameters);

        static int fcalls;

        AtomMatrix force(long nAtoms, AtomMatrix positions,
                         VectorXi atomicNrs, double *energy, Matrix3d box, VectorXi fixed);

        AtomMatrix IntraMolecularForce(long nAtoms, AtomMatrix positions, VectorXi atomicNrs, double *energy, Matrix3d box, VectorXi fixed);

        void virtual initialize() = 0;
        void virtual force(long nAtoms, const double *positions, 
                           const int *atomicNrs, double *forces, double *energy, 
                           const double *box, const int *fixed) = 0;
                   
        void virtual intraMolecularForce(long nAtoms, const double *positions, 
                           const int *atomicNrs, double *forces, double *energy, 
                           const double *box, const int *fixed) = 0;            
                           

        void virtual molecularVirial(long N, const double *R, const int *atomicNrs, double *F, double *U, const double *box, const int * fixed, double *virial)=0;   
        Matrix3d getMolecularVirial(long nAtoms, AtomMatrix positions,VectorXi atomicNrs, double *energy, Matrix3d box, VectorXi fixed);
        
        
        void virtual listMolecules(const long nAtoms, int & nMolecules, int *nAtomsPerMolecule, int *atomIds) = 0;

        void virtual dipoleMoment(double *D,const double *R, double *F, const double *box,const int * fixed)=0;
        Vector3d getDipoleMoment(long nAtoms,AtomMatrix positions, Matrix3d box, VectorXi fixed);
        
        static Potential* pot;

};

#endif
