#ifndef H2OCOCO2FORCEFIELDS_COCO_HPP
#define H2OCOCO2FORCEFIELDS_COCO_HPP

#include "potential_base.hpp"

namespace h2ococo2forcefields {
	class CoCo : virtual public h2ococo2forcefields::PotentialBase {
	public:
		//constructor
		CoCo();
		//destructor
		~CoCo() {}

        void computeC_O_(const int nCo,Co *const *const coList, double & energy, const double * const diagbox);
        void computeCOIntra(const int nCo, Co *const *const coList, double & energy, const double* const diagbox);                
        void computeInterMolecularCoCo(Co &co1, Co &co2, double &energy,double *force,const double* const diagbox);


        static char const * getName();///< Name of the potential.
            

	protected:


    	/** Interactions between two molecules.
			Coulomb interaction between two molecules. Full interaction (i.e. no cutoff).
			@param[in, out] co1 Molecule 1.
			@param[in, out] co2 Molecule 2.
			@param[in, out] U Add the potential energy to @a U.
			@see intermolecularFull() and intermolecularSwitching().
			@note The function add the force on charge N to Water::fn_ but does not spread it to Water::fh1_, etc ...
			@see spreadN().
			*/
		void coulombFull(Co & co1, Co & co2, double & U);
	
	    /** Interaction between two molecules.
	        Buckingham interaction between two co molecules.
	        @param[in,out] co1 Molecule of CO 1.
	        @param[in,out] co2 Molecule of CO 2.
	        @param[in,out] energy Buckingham potential energy is added to @a energy.
	        */
	    void buckinghamFull(Co & co1, Co & co2, double & energy);

        void calculateInternalGeometry(Co & co);

        void calcCO_charge(Co & co, double & qc, double & qo);	
	private:



		
	};

}

#endif
