#ifndef H2OCOCO2_GEOMETRY_HPP
#define H2OCOCO2_GEOMETRY_HPP
#include <cmath>

namespace h2ococo2forcefields{
    
    class Geometry{
        public:
            Geometry();
            Geometry(const double* const p);

            void setPeriodicity(const double periods[]);

            static double applyPeriodicity0(double r, double const period);
            static void applyPeriodicity0(double r[], double const periods[]) ;
            void returnCellVector(const double *r1,const double *r2, double *t);


        struct Vector3 {
            double v[3];///< Vector.
            double _1;///< Vector's norm.
            double _2;///< Vector's norm square.
        };

            double applyPeriodicity1(double r, int const axis);
            void applyPeriodicity1(double r[]);
            void distance(const double x[], const double y[], double z[], double & z1, double & z2);
            void distance(const double x[], const double y[], double z[], double & z1);
            void distance(const double x[], const double y[], double z[]);
            void distance(const double x[], const double y[], double & z1);
            void distance(const double x[], const double y[], Vector3 & z);
            static double unBreak0(double const r, double const ref, double const period);
            static void unBreak0(double r[], double const ref[], double const periods[]);            
            double unBreak1(double const r, double const ref, int const axis);
            void unBreak1(double r[], double const ref[]);            


            void calculateCentre(double const r1[], double const r2[], double rc[]);
            void calculateCentre(double const r1[], double const r2[], double const r3[], double rc[]);
            void calculateWeightedCentre(double const w1, double const w2, double const w3, 
                                         double const r1[], double const r2[], double const r3[], double rc[]);
            void calculateWeightedCentre(double const w1, double const w2, double const r1[], double const r2[], 
                                         double rc[]);                                     

            void spreadForce(double f1[], double f2[], double const fc[]);
            void spreadForce(double f1[], double f2[], double f3[], double const fc[]);
            void spreadWeightedForce(const double  w1,const double  w2,const double  w3, 
                                     double f1[], double f2[], double f3[], double fc[]);
            void spreadWeightedForce(double const w1, double const w2, double f1[], double f2[], double fn[]);

        private:

            double periods_[3];
            double inv_periods_[3];

    };

    inline void Geometry::distance(const double x[], const double y[], double z[], double & z1, double & z2)
    {
        double n;
        int m;
        for(int i=2; i>=0 ; --i) {
            z[i] =x[i]-y[i];
            n = z[i]*inv_periods_[i] + 0.5;
            m = (int)n;
            if (n < 0) -- m;
            z[i] -= m*periods_[i];        
        }
        z2 = z[0]*z[0]+z[1]*z[1]+z[2]*z[2];
        z1 = sqrt(z2);
    }

}


#endif
