#ifndef H2OCOCO2FORCEFIELDS_H2OCO_HPP
#define H2OCOCO2FORCEFIELDS_H2OCO_HPP

#include "potential_base.hpp"
namespace h2ococo2forcefields {
	class H2oCo : virtual public h2ococo2forcefields::PotentialBase {
	public:
		//constructor
		H2oCo();
		//destructor
		~H2oCo() {};

        static char const * getName();///< Name of the potential.
      
        void computeHH_O_C_O(const int nH2o , const int nCo, Water *const *const h2oList, Co *const *const coList, double & energy, const double * const diagbox);
        void computeInterMolecularH2oCo(Water &w, Co &co, double &energy,double *force,const double* const diagbox);

	private:
	
		/**Compute charges on CO molecule
			@param[in] co	Co molecule.
			@param[out] qc Charge on C atom.
			@param[out] qo Charge on O atom.
			*/
		void calcCO_charge(Co & co, double & qc, double & qo);
	
		
		/**Calculate Coulomb interactions, no cutoff.
			@param[in] 		co 	Co molecule.
			@param[in] 		w 		Water molecule.
			@param[in,out] U		potential energy.
			@param[in]		qco_c Charge on C atom in CO molecule.
			@param[in]		qco_o Charge on O atom in CO molecule.
			*/	
		void coulombFull(Co & co, Water & w, double &U, const double & qco_c, const double & qco_o);
	
		/**Compute buckingham interactions
			@param[in] 		co 	Co molecule.
			@param[in] 		w 		Water molecule.
			@param[in,out] U		potential energy.		
			*/
		void buckinghamFull(Co & co, Water & w, double & U);		
		

};
}

#endif
