#ifndef H2OCOCO2POT_HPP
#define H2OCOCO2POT_HPP

#include "Potential.h" //WARNING: replace with official EON version!

#include "tip4p.hpp"
#include "coco.hpp"
#include "h2oco.hpp"
#include "co2co2.hpp"
#include "h2oco2.hpp"
#include "molecules.hpp"
#include "water.hpp"
#include "co2.hpp"
#include "co.hpp"

class H2oCoCo2Pot : public Potential, 
                    private h2ococo2forcefields::H2oCo, 
                    private h2ococo2forcefields::CoCo, 
                    private h2ococo2forcefields::Tip4p, 
                    private h2ococo2forcefields::Co2Co2, 
                    private h2ococo2forcefields::H2oCo2
{
public:
	//constructor
	H2oCoCo2Pot();
    ~H2oCoCo2Pot();
		
	//to satisfy interface (demanded from Potential base class)
	void initialize(void) {}
	void cleanMemory(void) {}
	void force(long N, const double *R, const int *atomicNrs, double *F, double *U, const double *box, const int *fixed);
    void intraMolecularForce(long N, const double *R, const int *atomicNrs, double *F, double *U, const double *box, const int * fixed);	
	void molecularVirial(long N, const double *R, const int *atomicNrs, double *F, double *U, const double *box, const int * fixed, double *virial);
    void listMolecules(const long nAtoms, int & nMolecules, int * nAtomsPerMolecule, int * atomIds);
    void dipoleMoment(double *D,const double *R, double *F, const double *box,const int * fixed); 
private:
	unsigned int	nH2O_molecules;
	unsigned int	nCO_molecules;
    unsigned int    nCO2_molecules;

    bool            initialized;
    double          diagbox[3];
    
    h2ococo2forcefields::Molecules       *MolList;

	/** Compute the number of water molecules. 
		The order of the atoms is very important. For this function the order is H1, H1, H2, H2, etc ... , O1, O2, etc ...
		The numbers are for the molecules. The number of water molecules is determined from the number of H pairs in the atomicNrs array. 
		The number of CO molecules is then (N-3*nWater)/2.
		@param[in]  N		total number of atoms
		@param[in]  atomicNrs	atomic numbers of the atoms
		@warning Be careful with the order of the atoms.
	*/
	void  			calc_nMolecules(long N, const int *atomicNrs);
    void            initialize(long N, const double *R,double *F, const int *atomicNrs, const double *box);	
    void            initializeMolecularGeometries();

};
#endif

