#ifndef H2OCOCO2_POTENTIAL_PARAMETERS_HPP
#define H2OCOCO2_POTENTIAL_PARAMETERS_HPP

#include "unit_system.hpp"


namespace h2ococo2forcefields {
    using namespace unit_system;
    namespace parameters {

        //cutoff distances
        const double        cutoff_             = 10.0;
        const double        switchingWidth_     = 1.0;


        //molecular weights (for determining center of mass)
        const double        weightc_            = 12.0;    
        const double        weighto_            = 15.99491461956; 
        const double        weighth_            = 1.00794;

        //H2O intramolecular constants
        const double        tip4p_qh_           = 0.5564*ECHARGE;
        const double        tip4p_qm_           = -2*tip4p_qh_; 

        const double        tip4p_dom_rel_      = 0.13194;  
        const double        tip4p_theta_eq_     = 107.4*DEGREE;
        const double        tip4p_ktheta_       = 367.810*KJ_PER_MOL;
        const double        tip4p_beta_         = 22.87/NM;
        const double        tip4p_Dr_           = 432.581*KJ_PER_MOL;
        const double        tip4p_roh_eq_       = 0.9419*ANGSTROM;

        //CO intramolecular constants
        const double        co_qc_              =-0.47*ECHARGE;
        const double        co_qo_              =-0.615*ECHARGE;
        const double        co_sigmac_          = 3.844/ANGSTROM;
        const double        co_sigmao_          = 2.132/ANGSTROM;
        const double        co_re_              = 1.1282*ANGSTROM;
        const double        co_beta_            = 2.3281/ANGSTROM;
        const double        co_D_               = 11.2301*EV;

        //CO2 intramolecular constants
        /* EPM */        
        const double        co2_qc_             = 0.6645*ECHARGE;
        const double        co2_qo_             = -0.5*co2_qc_;
        const double        co2_re_             = 1.161*ANGSTROM;
        const double        co2_ktheta_         = 57*co2_re_*co2_re_*NEWTON/METRE;
        const double        co2_k1_             = 1550*NEWTON/METRE;
        const double        co2_k2_             = 130*NEWTON/METRE;

        /* EPM 2       
        const double        co2_qc_             = 0.6512*ECHARGE;
        const double        co2_qo_             = -0.5*co2_qc_;
        const double        co2_re_             = 1.149*ANGSTROM;
        const double        co2_ktheta_         = 57*co2_re_*co2_re_*NEWTON/METRE;
        const double        co2_k1_             = 1550*NEWTON/METRE;
        const double        co2_k2_             = 130*NEWTON/METRE;

        */

        //Tip4p constants
        const double        tip4p_epsilon_      = 93.2*KELVIN;
        const double        tip4p_sigma_        = 3.1644*ANGSTROM;


        //CO-CO constants
        const double        coco_csixco_ = 15.19*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double        coco_csixoo_ = 10.55*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double        coco_csixcc_ = 33.45*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;

        const double        coco_cbuckco_ = 1517*EV;
        const double        coco_cbuckoo_ = 6370*EV;
        const double        coco_cbuckcc_ = 361.4*EV;

        const double        coco_cexpco_ = 3.543/ANGSTROM;
        const double        coco_cexpoo_ = 4.252/ANGSTROM;
        const double        coco_cexpcc_ = 2.835/ANGSTROM;


        //CO2-CO2 constants
        /*EPM1 */        
        const double co2co2_epsiloncc_ = 28.999*KELVIN;
        const double co2co2_epsilonco_ = 49.060*KELVIN;
        const double co2co2_epsilonoo_ = 82.997*KELVIN;

        const double co2co2_sigmacc_ = 2.785*ANGSTROM;
        const double co2co2_sigmaco_ = 2.921*ANGSTROM;
        const double co2co2_sigmaoo_ = 3.064*ANGSTROM;


        /* EPM 2
        const double co2co2_epsiloncc_ = 28.129*KELVIN;
        const double co2co2_epsilonco_ = 47.588*KELVIN;
        const double co2co2_epsilonoo_ = 80.507*KELVIN;

        const double co2co2_sigmacc_ = 2.757*ANGSTROM;
        const double co2co2_sigmaco_ = 2.892*ANGSTROM;
        const double co2co2_sigmaoo_ = 3.033*ANGSTROM;
        */


        //H2O-CO2 constants
        const double h2oco2_csixhc_ = 7.3953*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double h2oco2_csixho_ = 0.0854*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double h2oco2_csixoc_ = 19.872*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double h2oco2_csixoo_ = 30.983*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;

        const double h2oco2_cbuckhc_ = 80.711*EV;
        const double h2oco2_cbuckho_ = 40.450*EV; 
        const double h2oco2_cbuckoc_ = 47.974*EV;
        const double h2oco2_cbuckoo_ = 5469.6*EV;        

        const double h2oco2_betahc_ = 3.00581/ANGSTROM;
        const double h2oco2_betaho_ = 3.52071/ANGSTROM;
        const double h2oco2_betaoc_ = 2.47961/ANGSTROM;
        const double h2oco2_betaoo_ = 3.92658/ANGSTROM;





/*
       //Fit with the tip4p2005f charge on the water molecule
        const double h2oco2_csixoo_ = 92.0160*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double h2oco2_csixoc_ = 48.1760*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double h2oco2_csixho_ = -3.0135*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double h2oco2_csixhc_ = 25.8375*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;

        const double h2oco2_cbuckoo_ = 1307.7330*EV;        
        const double h2oco2_cbuckoc_ = 59.5237*EV;
        const double h2oco2_cbuckho_ = 0.0594*EV; 
        const double h2oco2_cbuckhc_ = 290.8037*EV;

        const double h2oco2_betaoo_ = 3.1416/ANGSTROM;
        const double h2oco2_betaoc_ = 2.1223/ANGSTROM;
        const double h2oco2_betaho_ = 0.5893/ANGSTROM;
        const double h2oco2_betahc_ = 3.2816/ANGSTROM;
*/
        //H2O-CO constants
        const double h2oco_csixch_= 1.9421*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double h2oco_csixoh_= 0.0012903*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double h2oco_csixco_= 70.378*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;
        const double h2oco_csixoo_= 1.8897*EV*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM*ANGSTROM;

        const double h2oco_cbuckch_ = 677.23*EV;
        const double h2oco_cbuckoh_ = 537.70*EV;
        const double h2oco_cbuckco_ = 427.92*EV;
        const double h2oco_cbuckoo_ = 68674000*EV;

        const double h2oco_betach_ = 4.5056/ANGSTROM;
        const double h2oco_betaoh_ = 4.5505/ANGSTROM;
        const double h2oco_betaco_ = 2.7252/ANGSTROM;
        const double h2oco_betaoo_ = 8.0222/ANGSTROM;
        
        //CO-CO2 constants    

    }
}

#endif
