#include "water.hpp"

#include <iostream>
using namespace h2ococo2forcefields;




Water::Water(	double const rh1[], double const rh2[], double const ro[], double const rx[],
		 	 			double fh1[], double fh2[], double fo[], double fx[],const bool fixed) :
	 rh1_(rh1),
	 rh2_(rh2),
	 ro_(ro),
	 rx_(rx),
	 fh1_(fh1),
	 fh2_(fh2),
	 fo_(fo),
     fx_(fx),	 
     fixed_(fixed)	 					 	 			
{  }		

Water::Water(const Water & w, double fh1[], double fh2[], double fo[], double fx[]) :
	 rh1_(w.rh1_),
	 rh2_(w.rh2_),
	 ro_(w.ro_),
	 rx_(w.rx_),
	 fh1_(fh1),
	 fh2_(fh2),
	 fo_(fo),
     fx_(fx),
     fixed_(w.fixed_)
{ 
    for(int i=2;i>=0;--i) {
        rm_[i] = w.rm_[i];
        fm_[i] = 0.0;
        d1_[i] = w.d1_[i];
        d2_[i] = w.d2_[i];
    }
    d1_1_ = w.d1_1_;
    d2_1_ = w.d2_1_; 
}

Water::~Water() {

}

void Water::incrementForces(Water const & w) 
{
	for(int i=2; i >= 0; --i) {
		fh1_[i]+=w.fh1_[i];
		fh2_[i]+=w.fh2_[i];
		fo_[i] +=w.fo_[i];
        fx_[i] +=w.fx_[i];
        fm_[i] +=w.fm_[i];
	}
}

void Water::setRm(const double * const rm) {
    rm_[0] = rm[0];
    rm_[1] = rm[1];
    rm_[2] = rm[2];

    fm_[0] = 0.0; fm_[1] = 0.0; fm_[2] = 0.0;    
}

void Water::setD(const double * const d1, const double * const d2, const double & d1_1,const double & d2_1) {
    d1_[0] = d1[0]; d2_[0] = d2[0];
    d1_[1] = d1[1]; d2_[1] = d2[1];
    d1_[2] = d1[2]; d2_[2] = d2[2];
    d1_1_ = d1_1;
    d2_1_ = d2_1;

}

void Water::resetForces() {
    for(int i=2;i>=0;--i) {
        fh1_[i]=0.0;
        fh2_[i]=0.0;
        fo_[i] =0.0;
        fm_[i] =0.0;
        fx_[i] =0.0;
    }
    
}
